@@ -6,12 +6,15 @@ use strict;
 
 use Exporter;
 
-$Locale::Currency::Format::VERSION = '1.25';
+$Locale::Currency::Format::VERSION = '1.27';
 
 @Locale::Currency::Format::ISA     = qw(Exporter);
 @Locale::Currency::Format::EXPORT  = qw(
     currency_format
     currency_symbol
+    decimal_precision
+    decimal_separator
+    thousands_separator
     currency_set
     FMT_NOZEROS
     FMT_STANDARD
@@ -26,7 +29,8 @@ $Locale::Currency::Format::VERSION = '1.25';
 @Locale::Currency::Format::EXPORT_OK = qw($error);
 
 %Locale::Currency::Format::EXPORT_TAGS = (
-  DEFAULT => [@Locale::Currency::Format::EXPORT]
+  DEFAULT => [@Locale::Currency::Format::EXPORT],
+  default => [@Locale::Currency::Format::EXPORT],
 );
 
 $Locale::Currency::Format::error = q{};
@@ -132,6 +136,75 @@ sub currency_symbol {
     return $sym;
 }
 
+sub decimal_precision {
+    my ($code) = @_;
+
+    if (!defined $code) {
+        $::_error = 'Undefined currency code';
+        return;
+    }
+
+    my $cur = $currency{uc $code};
+    if (!$cur) {
+        $::_error = 'Invalid currency code';
+        return;
+    }
+
+    my $precision = $cur->[$frac_len];
+    if (!$precision) {
+        $::_error = 'Non-existant decimal precision';
+        return;
+    }
+
+    return $precision;
+}
+
+sub decimal_separator {
+    my ($code) = @_;
+
+    if (!defined $code) {
+        $::_error = 'Undefined currency code';
+        return;
+    }
+
+    my $cur = $currency{uc $code};
+    if (!$cur) {
+        $::_error = 'Invalid currency code';
+        return;
+    }
+
+    my $separator = $cur->[$dec_sep];
+    if (!$separator) {
+        $::_error = 'Non-existant decimal separator';
+        return;
+    }
+
+    return $separator;
+}
+
+sub thousands_separator {
+    my ($code) = @_;
+
+    if (!defined $code) {
+        $::_error = 'Undefined currency code';
+        return;
+    }
+
+    my $cur = $currency{uc $code};
+    if (!$cur) {
+        $::_error = 'Invalid currency code';
+        return;
+    }
+
+    my $separator = $cur->[$thou_sep];
+    if (!$separator) {
+        $::_error = 'Non-existant thousands separator';
+        return;
+    }
+
+    return $separator;
+}
+
 sub currency_set {
     my ($code, $tmpl, $style) = @_;
 
@@ -282,7 +355,7 @@ sub format_negative {
 #        name frac_len thou_sep dec_sep space_sep utf_sym htm_sym com_sym pre
 %currency = (
 AED => ["UAE Dirham",2,",","."," ",$EMPTY,$EMPTY,"Dhs.",1],
-AFA => ["Afghani",0,$EMPTY,$EMPTY,"\x{060B}","&#060B;",,$EMPTY,$EMPTY],
+AFA => ["Afghani",0,$EMPTY,$EMPTY,"\x{060B}","&#x060B;",,$EMPTY,$EMPTY],
 ALL => ["Lek",2,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 AMD => ["Armenian Dram",2,",",".","",$EMPTY,$EMPTY,"AMD",0],
 ANG => ["Antillian Guilder",2,".",","," ","\x{0192}","&#x0192;","NAf.",1],
@@ -296,7 +369,7 @@ BAM => ["Convertible Marks",2,",",".","",$EMPTY,$EMPTY,"AZM",0],
 BBD => ["Barbados Dollar",2,$EMPTY,$EMPTY,"","\x{0024}","&#x0024;",$EMPTY,$EMPTY],
 BDT => ["Taka",2,",","."," ",$EMPTY,$EMPTY,"Bt.",1],
 BEF => ["Belgian Franc",0,".",""," ","\x{20A3}","&#x20A3;","BEF",1],
-BGL => ["Lev",2," ",","," ",$EMPTY,$EMPTY,"lv",0],
+BGN => ["Lev",2," ",","," ",$EMPTY,$EMPTY,"lv",0],
 BHD => ["Bahraini Dinar",3,",","."," ",$EMPTY,$EMPTY,"BD",1],
 BIF => ["Burundi Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 BMD => ["Bermudian Dollar",2,",",".","","\x{0024}","&#x0024;","\$",1],
@@ -337,7 +410,7 @@ FKP => ["Pound",0,$EMPTY,$EMPTY,"","\x{00A3}","&#x00A3;",$EMPTY,$EMPTY],
 FRF => ["French Franc",2," ",","," ","\x{20A3}","&#x20A3;","FRF",0],
 GBP => ["Pound Sterling",2,",",".","","\x{00A3}","&#x00A3;","",1],
 GEL => ["Lari",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
-GHS => ["Cedi",2,",",".","","\x{20B5}","&#20B5;","\x{20B5}",1],
+GHS => ["Cedi",2,",",".","","\x{20B5}","&#x20B5;","\x{20B5}",1],
 GIP => ["Gibraltar Pound",2,",",".","","\x{00A3}","&#x00A3;","",1],
 GMD => ["Dalasi",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 GNF => ["Guinea Franc",$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY],
@@ -413,7 +486,7 @@ PYG => ["Guarani",0,$EMPTY,$EMPTY,"","\x{20B2}","&#20B2;","Gs.",$EMPTY],
 QAR => ["Qatari Rial",0,$EMPTY,$EMPTY,"","\x{FDFC}","&#xFDFC;",$EMPTY,$EMPTY],
 RON => ["Leu",2,".",","," ",$EMPTY,$EMPTY,"lei",0],
 RSD => ["Serbian Dinar",2,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,"din",0],
-RUB => ["Russian Ruble",2,".",",",$EMPTY,"\x{0440}\x{0443}\x{0431}","&#0440;&#0443;&#0431;","RUB",1],
+RUB => ["Russian Ruble",2,".",",",$EMPTY,"\x{0440}\x{0443}\x{0431}","&#x0440;&#x0443;&#x0431;","RUB",1],
 RWF => ["Rwanda Franc",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SAC => ["S. African Rand Commerc.",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 SAR => ["Saudi Riyal",2,",","."," ","\x{FDFC}","&#xFDFC;","SR",1],
@@ -485,6 +558,15 @@ Locale::Currency::Format - Perl functions for formatting monetary values
   $sym = currency_symbol('USD');                   # => $
   $sym = currency_symbol('GBP', SYM_HTML);         # => &#163;
 
+  $decimals = decimal_precision('USD');            # => 2
+  $decimals = decimal_precision('BHD');            # => 3
+
+  $thou_sep = thousands_separator('USD');          # => ,
+  $thou_sep = thousands_separator('EUR');          # => .
+
+  $dec_sep = decimal_separator('USD');             # => .
+  $dec_sep = decimal_separator('EUR');             # => ,
+
   currency_set('USD', '#.###,## $', FMT_COMMON);   # => set custom format
   currency_format('USD', 1000, FMT_COMMON);        # => 1.000,00 $
   currency_set('USD');                             # => reset default format
@@ -559,11 +641,41 @@ Default is a Unicode-based character. Upon failure, it returns I<undef> and an e
 		 character
         SYM_HTML returns the symbol (if exists) as a HTML escape
 
+=item C<decimal_precision(CODE)>
+
+For conveniences, the function B<decimal_precision> is provided to lookup the decimal
+precision for a given 3-letter currency code.
+
+Upon failure, it returns I<undef> and an error message is stored in B<$Locale::Currency::Format::error>.
+
+    CODE
+        A 3-letter currency code as specified in ISO 4217
+
+=item C<decimal_separator(CODE)>
+
+For conveniences, the function B<decimal_separator> is provided to lookup the decimal
+separator for a given 3-letter currency code.
+
+Upon failure, it returns I<undef> and an error message is stored in B<$Locale::Currency::Format::error>.
+
+    CODE
+        A 3-letter currency code as specified in ISO 4217
+
+=item C<thousands_separator(CODE)>
+
+For conveniences, the function B<thousands_separator> is provided to lookup the thousands 
+separator for a given 3-letter currency code.
+
+Upon failure, it returns I<undef> and an error message is stored in B<$Locale::Currency::Format::error>.
+
+    CODE
+        A 3-letter currency code as specified in ISO 4217
+
 =item C<currency_set(CODE [, TEMPLATE, FORMAT])>
 
 B<currency_set> can be used to set a custom format for a currency instead of the provided format. For example, in many non-English speaking countries, the US dollars might be displayed as B<2.999,99 $> instead of the usual B<$2,999.99>. In order to accomplish this, one will need to do as follows:
 
-    use Locale::Currency::Format qw(:DEFAULT $error);
+    use Locale::Currency::Format qw(:default $error);
 
     my $currency = 'USD';
     my $template = '#.###,## $';
@@ -587,7 +699,7 @@ The arguments to B<currency_set> are:
         Ex: currency_set('GBP', "\x{00A3}#,###.##", FMT_SYMBOL)
 
         If an HTML symbol is wanted, escape its equivalent HTML code.
-        Ex: currency_set('GBP', '&#00A3;#,###.##', FMT_HTML)
+        Ex: currency_set('GBP', '&#x00A3;#,###.##', FMT_HTML)
 
     FORMAT
         This argument is required if TEMPLATE is present.
@@ -646,6 +758,10 @@ L<Locale::Currency>, L<Math::Currency>, L<Number::Format>, L<perluniintro>, L<pe
 
 If you find any inaccurate or missing information, please send your comments to L<tnguyen@cpan.org>. Your effort is certainly appreciated!
 
+=head1 CONTRIBUTOR(S)
+
+James Kiser <james.kiser@gmail.com>
+
 =head1 AUTHOR
 
 Tan D Nguyen <tnguyen@cpan.org>
